Certificate Authorities — django-pki v0.20.0 documentation

### Navigation

- index
- django-pki v0.20.0 documentation »

# Certificate Authorities

## Create top-level RootCA

- Pki -> Certificate Authorities -> Add Certificate Authority

1. Common name: CN in the certificate’s subject
2. Name: Internal name. Automatically created
3. Country: 2 letter country code
4. State: The state
5. Locality: The city
6. Organization: The Organization
7. OU: Organizational unit
8. Email: The email address associalted with the certificate
9. Key length: 1024, 2048 or 4096 bit
10. Valid days: How many days is this certificate valid

11. xxx

### Navigation

- index
- django-pki v0.20.0 documentation »